// APISampleDoc.cpp : implementation of the CAPISampleDoc class
//

#include "stdafx.h"
#include "APISample.h"

#include "APISampleDoc.h"
#include "SHAPI.h"
#include "ConfigDlg.h"
#include "SweepDlg.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CAPISampleDoc

IMPLEMENT_DYNCREATE(CAPISampleDoc, CDocument)

BEGIN_MESSAGE_MAP(CAPISampleDoc, CDocument)
	//{{AFX_MSG_MAP(CAPISampleDoc)
	ON_COMMAND(ID_ACTION_INITIALIZE, OnActionInitialize)
	ON_COMMAND(ID_ACTION_CONFIGURE, OnActionConfigure)
	ON_COMMAND(ID_ACTION_FASTSWEEP, OnActionFastsweep)
	ON_COMMAND(ID_ACTION_SLOWSWEEP, OnActionSlowsweep)
	ON_COMMAND(ID_ACTION_PRESETSIGNALHOUND25SEC, OnActionPresetsignalhound25sec)
	ON_COMMAND(ID_ACTION_GETIQDATA, OnActionGetiqdata)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CAPISampleDoc construction/destruction

CAPISampleDoc::CAPISampleDoc()
{
	bHaveValidPlot = FALSE;
	sampleCount = 0;
}

CAPISampleDoc::~CAPISampleDoc()
{
}

BOOL CAPISampleDoc::OnNewDocument()
{
	if (!CDocument::OnNewDocument())
		return FALSE;

	// TODO: add reinitialization code here
	// (SDI documents will reuse this document)

	return TRUE;
}



/////////////////////////////////////////////////////////////////////////////
// CAPISampleDoc serialization

void CAPISampleDoc::Serialize(CArchive& ar)
{
	if (ar.IsStoring())
	{
		// TODO: add storing code here
	}
	else
	{
		// TODO: add loading code here
	}
}

/////////////////////////////////////////////////////////////////////////////
// CAPISampleDoc diagnostics

#ifdef _DEBUG
void CAPISampleDoc::AssertValid() const
{
	CDocument::AssertValid();
}

void CAPISampleDoc::Dump(CDumpContext& dc) const
{
	CDocument::Dump(dc);
}
#endif //_DEBUG

/////////////////////////////////////////////////////////////////////////////
// CAPISampleDoc commands

void CAPISampleDoc::OnActionInitialize() 
{
	// *** Call the initialize function and report the result ***
	CString str1;
	str1.Format("Initialize returned %d",SHAPI_Initialize() );
	MessageBox(NULL,str1,"Return Value (0 is success)",MB_OK);
	
}

void CAPISampleDoc::OnActionConfigure() 
{
	// *** Open a dialog box to input configuration settings ***

	CConfigDlg	dlg;
	if(IDOK==dlg.DoModal())
	{
		CString str1;

		// *** Call the configure function and report the result ***
		int returnVal = SHAPI_Configure(dlg.m_Atten, dlg.m_MixerBand, dlg.m_Sensitivity,
			dlg.m_Decimation, dlg.m_IFPath);
		str1.Format("Configure returned %d", returnVal);
		MessageBox(NULL,str1,"Return Value (0 is success)",MB_OK);
		myDecimation = dlg.m_Decimation;
	}
	
}

void CAPISampleDoc::OnActionFastsweep() 
{
	CSweepDlg dlg;
	if(IDOK==dlg.DoModal())
	{
		// *** Free any previously allocated memory ***
		if(bHaveValidPlot)
		{
			bHaveValidPlot = FALSE;
			delete [] myData;
			sampleCount=0;
		}

		int avgCount=4;
		if(dlg.m_FFTSize > 16384) avgCount=1;
		startFreq = dlg.m_StartFreq;
		stopFreq = dlg.m_StopFreq;

		// *** Find out how much memory to allocate ***

		int bufsize = SHAPI_GetFastSweepCount(startFreq, stopFreq, dlg.m_FFTSize);

		// *** Allocate the memory ***
		myData = new double[bufsize];
		sampleCount = bufsize;

		// *** Get the RBW ***
		myRBW = SHAPI_GetRBW(dlg.m_FFTSize,myDecimation);

		// *** Get the data ***
		SHAPI_GetFastSweep(myData,dlg.m_StartFreq, dlg.m_StopFreq, sampleCount, dlg.m_FFTSize,0);

		// *** Plot the data ***
		bHaveValidPlot = TRUE;
		UpdateAllViews(NULL);
	}
	
}

void CAPISampleDoc::OnActionSlowsweep() 
{
	CSweepDlg dlg;
	if(IDOK==dlg.DoModal())
	{
		// *** Free any previously allocated memory ***
		if(bHaveValidPlot)
		{
			bHaveValidPlot = FALSE;
			delete [] myData;
			sampleCount=0;
		}

		// *** Set averaging to 4, unless this would exceed 64K samples ***
		int avgCount=4;
		if(dlg.m_FFTSize > 16384) avgCount=1;
		startFreq = dlg.m_StartFreq;
		stopFreq = dlg.m_StopFreq;

		// *** Find out how much memory to allocate ***
		int bufsize = SHAPI_GetSlowSweepCount(startFreq, stopFreq, dlg.m_FFTSize);
		myData = new double[bufsize];
		sampleCount = bufsize;

		// *** Get the RBW ***
		myRBW = SHAPI_GetRBW(dlg.m_FFTSize,myDecimation);

		// *** Get the data ***
		SHAPI_GetSlowSweep(myData,dlg.m_StartFreq, dlg.m_StopFreq, sampleCount, dlg.m_FFTSize, avgCount);

		// *** Plot the data ***
		bHaveValidPlot = TRUE;
		UpdateAllViews(NULL);
	}
	
}




void CAPISampleDoc::OnActionPresetsignalhound25sec() 
{
	SHAPI_CyclePort();	
}

void CAPISampleDoc::OnActionGetiqdata() 
{
		// *** Free any previously allocated memory ***
		if(bHaveValidPlot)
		{
			bHaveValidPlot = FALSE;
			delete [] myData;
			sampleCount=0;
		}

		int * pIDATA = new int[512];
		int * pQDATA = new int[512];

		myData = new double[512];
		sampleCount = 512;
		// *** Get the data ***
		double myFreq = 213.0e6;
		SHAPI_GetIQDataPacket(pIDATA,pQDATA,myFreq,512); //Fixed 213 MHz.

		startFreq = 0.0;
		stopFreq = 0.0;

		// *** Plot the I channel data ***
		for(int i=0; i<512; i++)
			myData[i] = pIDATA[i];

		bHaveValidPlot = TRUE;
		UpdateAllViews(NULL);
	
	CString dbg;
	dbg.Format("Ctr Freq: %f",myFreq);
	MessageBox(NULL,dbg,"DEBUG",MB_OK);
}
