/*++

Copyright (c) 2010 Test Equipment Plus.

Module Name:

    SHAPI.h

Abstract:

    Native Signal Hound / USB device driver for Signal Hound Firmware version 1.2 or later
    Signal Hound API library definitions


Revision History:

    3/09/2010   JBC     Created.
    3/10/2010   JBC     Added function calls from SH_API.dll
	
	
--*/

#pragma once

//////////////////////////////////////////////////////////
// double SHAPI_GetRBW(int FFTSize, int decimation)
// Arguments: FFT size, decimation setting
// Returns calculated estimated RBW.
//////////////////////////////////////////////////////////
__declspec( dllimport ) double SHAPI_GetRBW(int FFTSize, int decimation);


//////////////////////////////////////////////////////////
// int SHAPI_Initialize()
// Initializes USB and loads cal table.
// TAKES 15 seconds to complete!!!
// Arguments: none 
// Returns 0 for success, otherwise returns error code.
//////////////////////////////////////////////////////////
__declspec( dllimport ) int WINAPI SHAPI_Initialize();


//////////////////////////////////////////////////////////
// int SHAPI_SetAttenuator(double attenVal)
// Sets attenuator to nearest value of 0,5,10, or 15 dB
// Arguments: double attenVal.
// Returns 0 for success, otherwise returns error code.
//////////////////////////////////////////////////////////
__declspec( dllimport ) int WINAPI SHAPI_SetAttenuator(double attenVal);


//////////////////////////////////////////////////////////
// int SHAPI_SelectExt10MHz()
// Selects external reference
// Returns 0 for success, otherwise returns error code.
//////////////////////////////////////////////////////////
__declspec( dllimport ) int WINAPI SHAPI_SelectExt10MHz();


//////////////////////////////////////////////////////////
// SHAPI_Configure(double attenVal, )
// Sets attenuator to nearest value of 0,5,10, or 15 dB
// Selects mixer as either low band (value=0) or high band (value=1)
// Selects sensitivity as 0=low, 1=mid, or 2=high sensitivity
// Selects decimation as [1..16]
// Selects IF path as either 2.92 (value=1) or 10.7 MHz (value=0)
// Selects clock as 23.33 MHz (value=0) or 22.5 MHz (value=1) 
// Arguments: double attenVal=10, int mixerBand=1, int sensitivity=0,  
//												   int decimation=1, int useIF2_9=0, int ADCclock=0
// Returns 0 for success, otherwise returns error code.
//////////////////////////////////////////////////////////
__declspec( dllimport ) int WINAPI SHAPI_Configure(double attenVal=10.0, int mixerBand=1, int sensitivity=0,  
												   int decimation=1, int useIF2_9=0, int ADCclock=0);


//////////////////////////////////////////////////////////
// SHAPI_GetSlowSweep
// See Signal Hound API documentation
//////////////////////////////////////////////////////////
__declspec( dllimport ) int WINAPI SHAPI_GetSlowSweep(double * dBArray, double startFreq, double stopFreq,  
													  int &returnCount, int FFTSize=1024, 
													  int avgCount=16, int imageHandling=0);


													  
//////////////////////////////////////////////////////////
// SHAPI_GetFastSweep
// See Signal Hound API documentation
//////////////////////////////////////////////////////////
__declspec( dllimport ) int WINAPI SHAPI_GetFastSweep(double * dBArray, double startFreq, double stopFreq,  
													  int &returnCount, int FFTSize=16, int imageHandling=0);

//////////////////////////////////////////////////////////
// SHAPI_GetSlowSweepCount
// Returns number of samples in proposed sweep
//////////////////////////////////////////////////////////
__declspec( dllexport ) int WINAPI SHAPI_GetSlowSweepCount(double startFreq, double stopFreq, int FFTSize);

//////////////////////////////////////////////////////////
// SHAPI_GetFastSweepCount
// Returns number of samples in proposed sweep
//////////////////////////////////////////////////////////
__declspec( dllimport ) int WINAPI SHAPI_GetFastSweepCount(double startFreq, double stopFreq,int FFTSize);

//////////////////////////////////////////////////////////
// SHAPI_CyclePort
// Returns 0 for success, or error code.
//////////////////////////////////////////////////////////
__declspec( dllimport ) int WINAPI SHAPI_CyclePort();

//////////////////////////////////////////////////////////
// SHAPI_GetIQDataPacket
// Returns 0 for success, or error code.
//////////////////////////////////////////////////////////
__declspec( dllimport ) int WINAPI SHAPI_GetIQDataPacket(int * pIData, int * pQData, double &centerFreq, int size);

